@@ -26,9 +26,9 @@ extern "C" fn os_handler(_: nix::libc::c_int) {
     }
 }
 
-// pipe2(2) is not available on macOS or iOS, so we need to use pipe(2) and fcntl(2)
+// pipe2(2) is not available on macOS, iOS or Haiku, so we need to use pipe(2) and fcntl(2)
 #[inline]
-#[cfg(any(target_os = "ios", target_os = "macos"))]
+#[cfg(any(target_os = "ios", target_os = "macos", target_os = "haiku"))]
 fn pipe2(flags: nix::fcntl::OFlag) -> nix::Result<(RawFd, RawFd)> {
     use nix::fcntl::{fcntl, FcntlArg, FdFlag, OFlag};
 
@@ -59,7 +59,7 @@ fn pipe2(flags: nix::fcntl::OFlag) -> nix::Result<(RawFd, RawFd)> {
 }
 
 #[inline]
-#[cfg(not(any(target_os = "ios", target_os = "macos")))]
+#[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "haiku")))]
 fn pipe2(flags: nix::fcntl::OFlag) -> nix::Result<(RawFd, RawFd)> {
     unistd::pipe2(flags)
 }
@@ -99,6 +99,7 @@ pub unsafe fn init_os_handler() -> Result<(), Error> {
         signal::SigSet::empty(),
     );
 
+    #[allow(unused_variables)]
     let sigint_old = match signal::sigaction(signal::Signal::SIGINT, &new_action) {
         Ok(old) => old,
         Err(e) => return Err(close_pipe(e)),
